@@ -33,40 +33,38 @@
 #include "gstscheduler.h"
 #include "gstindex.h"
 
-static GstElementDetails gst_bin_details = GST_ELEMENT_DETAILS (
-  "Generic bin",
-  "Generic/Bin",
-  "Simple container object",
-  "Erik Walthinsen <omega@cse.ogi.edu>"
-);
+static GstElementDetails gst_bin_details = GST_ELEMENT_DETAILS ("Generic bin",
+    "Generic/Bin",
+    "Simple container object",
+    "Erik Walthinsen <omega@cse.ogi.edu>");
 
 GType _gst_bin_type = 0;
 
-static gboolean _gst_boolean_did_something_accumulator (GSignalInvocationHint *ihint,
-    GValue *return_accu, const GValue *handler_return, gpointer dummy);
+static gboolean _gst_boolean_did_something_accumulator (GSignalInvocationHint *
+    ihint, GValue * return_accu, const GValue * handler_return, gpointer dummy);
 
-static void 			gst_bin_dispose 		(GObject * object);
+static void gst_bin_dispose (GObject * object);
 
-static GstElementStateReturn	gst_bin_change_state		(GstElement *element);
-static GstElementStateReturn	gst_bin_change_state_norecurse	(GstBin *bin);
+static GstElementStateReturn gst_bin_change_state (GstElement * element);
+static GstElementStateReturn gst_bin_change_state_norecurse (GstBin * bin);
 
 #ifndef GST_DISABLE_INDEX
-static void 			gst_bin_set_index 		(GstElement *element, GstIndex *index);
+static void gst_bin_set_index (GstElement * element, GstIndex * index);
 #endif
 
-static void 			gst_bin_add_func 		(GstBin *bin, GstElement *element);
-static void 			gst_bin_remove_func 		(GstBin *bin, GstElement *element);
-static void			gst_bin_child_state_change_func (GstBin *bin, GstElementState oldstate, 
-                                				 GstElementState newstate, GstElement *child);
+static void gst_bin_add_func (GstBin * bin, GstElement * element);
+static void gst_bin_remove_func (GstBin * bin, GstElement * element);
+static void gst_bin_child_state_change_func (GstBin * bin,
+    GstElementState oldstate, GstElementState newstate, GstElement * child);
 
-static GstClock* 		gst_bin_get_clock_func 		(GstElement *element);
-static void	 		gst_bin_set_clock_func 		(GstElement *element, GstClock *clock);
+static GstClock *gst_bin_get_clock_func (GstElement * element);
+static void gst_bin_set_clock_func (GstElement * element, GstClock * clock);
 
-static gboolean 		gst_bin_iterate_func 		(GstBin *bin);
+static gboolean gst_bin_iterate_func (GstBin * bin);
 
 #ifndef GST_DISABLE_LOADSAVE
-static xmlNodePtr 		gst_bin_save_thyself 		(GstObject * object, xmlNodePtr parent);
-static void 			gst_bin_restore_thyself 	(GstObject * object, xmlNodePtr self);
+static xmlNodePtr gst_bin_save_thyself (GstObject * object, xmlNodePtr parent);
+static void gst_bin_restore_thyself (GstObject * object, xmlNodePtr self);
 #endif
 
 /* Bin signals and args */
@@ -81,12 +79,12 @@ enum
 enum
 {
   ARG_0
-  /* FILL ME */
+      /* FILL ME */
 };
 
-static void 			gst_bin_base_init 		(gpointer g_class);
-static void 			gst_bin_class_init 		(GstBinClass * klass);
-static void 			gst_bin_init 			(GstBin * bin);
+static void gst_bin_base_init (gpointer g_class);
+static void gst_bin_class_init (GstBinClass * klass);
+static void gst_bin_init (GstBin * bin);
 
 static GstElementClass *parent_class = NULL;
 static guint gst_bin_signals[LAST_SIGNAL] = { 0 };
@@ -108,7 +106,8 @@ gst_bin_get_type (void)
       NULL
     };
 
-    _gst_bin_type = g_type_register_static (GST_TYPE_ELEMENT, "GstBin", &bin_info, 0);
+    _gst_bin_type =
+        g_type_register_static (GST_TYPE_ELEMENT, "GstBin", &bin_info, 0);
   }
   return _gst_bin_type;
 }
@@ -117,7 +116,7 @@ static void
 gst_bin_base_init (gpointer g_class)
 {
   GstElementClass *gstelement_class = GST_ELEMENT_CLASS (g_class);
-  
+
   gst_element_class_set_details (gstelement_class, &gst_bin_details);
 }
 
@@ -135,40 +134,42 @@ gst_bin_class_init (GstBinClass * klass)
   parent_class = g_type_class_ref (GST_TYPE_ELEMENT);
 
   gst_bin_signals[ELEMENT_ADDED] =
-    g_signal_new ("element_added", G_TYPE_FROM_CLASS (klass), G_SIGNAL_RUN_FIRST,
-		  G_STRUCT_OFFSET (GstBinClass, element_added), NULL, NULL,
-		  gst_marshal_VOID__OBJECT, G_TYPE_NONE, 1, GST_TYPE_ELEMENT);
+      g_signal_new ("element-added", G_TYPE_FROM_CLASS (klass),
+      G_SIGNAL_RUN_FIRST, G_STRUCT_OFFSET (GstBinClass, element_added), NULL,
+      NULL, gst_marshal_VOID__OBJECT, G_TYPE_NONE, 1, GST_TYPE_ELEMENT);
   gst_bin_signals[ELEMENT_REMOVED] =
-    g_signal_new ("element_removed", G_TYPE_FROM_CLASS (klass), G_SIGNAL_RUN_FIRST,
-		  G_STRUCT_OFFSET (GstBinClass, element_removed), NULL, NULL,
-		  gst_marshal_VOID__OBJECT, G_TYPE_NONE, 1, GST_TYPE_ELEMENT);
+      g_signal_new ("element-removed", G_TYPE_FROM_CLASS (klass),
+      G_SIGNAL_RUN_FIRST, G_STRUCT_OFFSET (GstBinClass, element_removed), NULL,
+      NULL, gst_marshal_VOID__OBJECT, G_TYPE_NONE, 1, GST_TYPE_ELEMENT);
   gst_bin_signals[ITERATE] =
-    g_signal_new ("iterate", G_TYPE_FROM_CLASS (klass), G_SIGNAL_RUN_LAST,
-		  G_STRUCT_OFFSET (GstBinClass, iterate),
-                  _gst_boolean_did_something_accumulator, NULL,
-		  gst_marshal_BOOLEAN__VOID, G_TYPE_BOOLEAN, 0);
+      g_signal_new ("iterate", G_TYPE_FROM_CLASS (klass), G_SIGNAL_RUN_LAST,
+      G_STRUCT_OFFSET (GstBinClass, iterate),
+      _gst_boolean_did_something_accumulator, NULL, gst_marshal_BOOLEAN__VOID,
+      G_TYPE_BOOLEAN, 0);
 
-  gobject_class->dispose 		= GST_DEBUG_FUNCPTR (gst_bin_dispose);
+  gobject_class->dispose = GST_DEBUG_FUNCPTR (gst_bin_dispose);
 
 #ifndef GST_DISABLE_LOADSAVE
-  gstobject_class->save_thyself 	= GST_DEBUG_FUNCPTR (gst_bin_save_thyself);
-  gstobject_class->restore_thyself 	= GST_DEBUG_FUNCPTR (gst_bin_restore_thyself);
+  gstobject_class->save_thyself = GST_DEBUG_FUNCPTR (gst_bin_save_thyself);
+  gstobject_class->restore_thyself =
+      GST_DEBUG_FUNCPTR (gst_bin_restore_thyself);
 #endif
 
-  gstelement_class->change_state 	= GST_DEBUG_FUNCPTR (gst_bin_change_state);
+  gstelement_class->change_state = GST_DEBUG_FUNCPTR (gst_bin_change_state);
 #ifndef GST_DISABLE_INDEX
-  gstelement_class->set_index	 	= GST_DEBUG_FUNCPTR (gst_bin_set_index);
+  gstelement_class->set_index = GST_DEBUG_FUNCPTR (gst_bin_set_index);
 #endif
 
-  klass->add_element 			= GST_DEBUG_FUNCPTR (gst_bin_add_func);
-  klass->remove_element 		= GST_DEBUG_FUNCPTR (gst_bin_remove_func);
-  klass->child_state_change		= GST_DEBUG_FUNCPTR (gst_bin_child_state_change_func);
-  klass->iterate 			= GST_DEBUG_FUNCPTR (gst_bin_iterate_func);
+  klass->add_element = GST_DEBUG_FUNCPTR (gst_bin_add_func);
+  klass->remove_element = GST_DEBUG_FUNCPTR (gst_bin_remove_func);
+  klass->child_state_change =
+      GST_DEBUG_FUNCPTR (gst_bin_child_state_change_func);
+  klass->iterate = GST_DEBUG_FUNCPTR (gst_bin_iterate_func);
 }
 
 static gboolean
-_gst_boolean_did_something_accumulator (GSignalInvocationHint *ihint,
-    GValue *return_accu, const GValue *handler_return, gpointer dummy)
+_gst_boolean_did_something_accumulator (GSignalInvocationHint * ihint,
+    GValue * return_accu, const GValue * handler_return, gpointer dummy)
 {
   gboolean did_something;
 
@@ -205,19 +206,19 @@ gst_bin_new (const gchar * name)
   return gst_element_factory_make ("bin", name);
 }
 
-static GstClock*
-gst_bin_get_clock_func (GstElement *element)
+static GstClock *
+gst_bin_get_clock_func (GstElement * element)
 {
-  if (GST_ELEMENT_SCHED (element)) 
+  if (GST_ELEMENT_SCHED (element))
     return gst_scheduler_get_clock (GST_ELEMENT_SCHED (element));
 
   return NULL;
 }
 
 static void
-gst_bin_set_clock_func (GstElement *element, GstClock *clock)
+gst_bin_set_clock_func (GstElement * element, GstClock * clock)
 {
-  if (GST_ELEMENT_SCHED (element)) 
+  if (GST_ELEMENT_SCHED (element))
     gst_scheduler_use_clock (GST_ELEMENT_SCHED (element), clock);
 }
 
@@ -229,8 +230,8 @@ gst_bin_set_clock_func (GstElement *element, GstClock *clock)
  *
  * Returns: the #GstClock of the bin
  */
-GstClock*
-gst_bin_get_clock (GstBin *bin)
+GstClock *
+gst_bin_get_clock (GstBin * bin)
 {
   g_return_val_if_fail (bin != NULL, NULL);
   g_return_val_if_fail (GST_IS_BIN (bin), NULL);
@@ -247,7 +248,7 @@ gst_bin_get_clock (GstBin *bin)
  * force it to use no clock at all.
  */
 void
-gst_bin_use_clock (GstBin *bin, GstClock *clock)
+gst_bin_use_clock (GstBin * bin, GstClock * clock)
 {
   g_return_if_fail (GST_IS_BIN (bin));
 
@@ -261,20 +262,20 @@ gst_bin_use_clock (GstBin *bin, GstClock *clock)
  * Let the bin select a clock automatically.
  */
 void
-gst_bin_auto_clock (GstBin *bin)
+gst_bin_auto_clock (GstBin * bin)
 {
   g_return_if_fail (GST_IS_BIN (bin));
 
-  if (GST_ELEMENT_SCHED (bin)) 
+  if (GST_ELEMENT_SCHED (bin))
     gst_scheduler_auto_clock (GST_ELEMENT_SCHED (bin));
 }
 
 #ifndef GST_DISABLE_INDEX
 static void
-gst_bin_set_index (GstElement *element, GstIndex *index)
+gst_bin_set_index (GstElement * element, GstIndex * index)
 {
   GstBin *bin = GST_BIN (element);
-  
+
   g_return_if_fail (GST_IS_BIN (bin));
 
   g_list_foreach (bin->children, (GFunc) gst_element_set_index, index);
@@ -282,27 +283,28 @@ gst_bin_set_index (GstElement *element, GstIndex *index)
 #endif
 
 static void
-gst_bin_set_element_sched (GstElement *element, GstScheduler *sched)
+gst_bin_set_element_sched (GstElement * element, GstScheduler * sched)
 {
   GST_CAT_LOG (GST_CAT_SCHEDULING, "setting element \"%s\" sched to %p",
-               GST_ELEMENT_NAME (element), sched);
+      GST_ELEMENT_NAME (element), sched);
 
   /* if it's actually a Bin */
   if (GST_IS_BIN (element)) {
     if (GST_FLAG_IS_SET (element, GST_BIN_FLAG_MANAGER)) {
       GST_CAT_DEBUG_OBJECT (GST_CAT_PARENTAGE, element,
-                            "child is already a manager, not resetting sched");
+          "child is already a manager, not resetting sched");
       if (GST_ELEMENT_SCHED (element))
         gst_scheduler_add_scheduler (sched, GST_ELEMENT_SCHED (element));
       return;
     }
 
     GST_CAT_DEBUG_OBJECT (GST_CAT_PARENTAGE, element,
-                          "setting child bin's scheduler to be the same as the parent's");
+        "setting child bin's scheduler to be the same as the parent's");
     gst_scheduler_add_element (sched, element);
 
     /* set the children's schedule */
-    g_list_foreach (GST_BIN (element)->children, (GFunc) gst_bin_set_element_sched, sched);
+    g_list_foreach (GST_BIN (element)->children,
+        (GFunc) gst_bin_set_element_sched, sched);
   }
   /* otherwise, if it's just a regular old element */
   else {
@@ -326,7 +328,7 @@ gst_bin_set_element_sched (GstElement *element, GstScheduler *sched)
       if (GST_PAD_PEER (pad)) {
         if (gst_pad_get_scheduler (GST_PAD_PEER (pad)) == sched) {
           GST_CAT_LOG (GST_CAT_SCHEDULING,
-                       "peer is in same scheduler, telling scheduler");
+              "peer is in same scheduler, telling scheduler");
 
           if (GST_PAD_IS_SRC (pad))
             gst_scheduler_pad_link (sched, pad, GST_PAD_PEER (pad));
@@ -340,30 +342,32 @@ gst_bin_set_element_sched (GstElement *element, GstScheduler *sched)
 
 
 static void
-gst_bin_unset_element_sched (GstElement *element, GstScheduler *sched)
+gst_bin_unset_element_sched (GstElement * element, GstScheduler * sched)
 {
   if (GST_ELEMENT_SCHED (element) == NULL) {
     GST_CAT_DEBUG (GST_CAT_SCHEDULING, "element \"%s\" has no scheduler",
-	      GST_ELEMENT_NAME (element));
+        GST_ELEMENT_NAME (element));
     return;
   }
 
-  GST_CAT_DEBUG (GST_CAT_SCHEDULING, "removing element \"%s\" from its sched %p",
-                 GST_ELEMENT_NAME (element), GST_ELEMENT_SCHED (element));
+  GST_CAT_DEBUG (GST_CAT_SCHEDULING,
+      "removing element \"%s\" from its sched %p", GST_ELEMENT_NAME (element),
+      GST_ELEMENT_SCHED (element));
 
   /* if it's actually a Bin */
   if (GST_IS_BIN (element)) {
 
     if (GST_FLAG_IS_SET (element, GST_BIN_FLAG_MANAGER)) {
       GST_CAT_DEBUG_OBJECT (GST_CAT_PARENTAGE, element,
-                            "child is already a manager, not unsetting sched");
+          "child is already a manager, not unsetting sched");
       if (sched) {
         gst_scheduler_remove_scheduler (sched, GST_ELEMENT_SCHED (element));
       }
       return;
     }
     /* for each child, remove them from their schedule */
-    g_list_foreach (GST_BIN (element)->children, (GFunc) gst_bin_unset_element_sched, sched);
+    g_list_foreach (GST_BIN (element)->children,
+        (GFunc) gst_bin_unset_element_sched, sched);
 
     gst_scheduler_remove_element (GST_ELEMENT_SCHED (element), element);
   }
@@ -386,7 +390,8 @@ gst_bin_unset_element_sched (GstElement *element, GstScheduler *sched)
       /* if the peer element exists and is a candidate */
       if (GST_PAD_PEER (pad)) {
         if (gst_pad_get_scheduler (GST_PAD_PEER (pad)) == sched) {
-          GST_CAT_LOG (GST_CAT_SCHEDULING, "peer is in same scheduler, telling scheduler");
+          GST_CAT_LOG (GST_CAT_SCHEDULING,
+              "peer is in same scheduler, telling scheduler");
 
           if (GST_PAD_IS_SRC (pad))
             gst_scheduler_pad_unlink (sched, pad, GST_PAD_PEER (pad));
@@ -409,7 +414,7 @@ gst_bin_unset_element_sched (GstElement *element, GstScheduler *sched)
  * Add a list of elements to a bin. Uses #gst_bin_add.
  */
 void
-gst_bin_add_many (GstBin *bin, GstElement *element_1, ...)
+gst_bin_add_many (GstBin * bin, GstElement * element_1, ...)
 {
   va_list args;
 
@@ -420,15 +425,15 @@ gst_bin_add_many (GstBin *bin, GstElement *element_1, ...)
 
   while (element_1) {
     gst_bin_add (bin, element_1);
-    
-    element_1 = va_arg (args, GstElement*);
+
+    element_1 = va_arg (args, GstElement *);
   }
 
   va_end (args);
 }
 
 static void
-gst_bin_add_func (GstBin *bin, GstElement *element)
+gst_bin_add_func (GstBin * bin, GstElement * element)
 {
   gint state_idx = 0;
   GstElementState state;
@@ -438,11 +443,10 @@ gst_bin_add_func (GstBin *bin, GstElement *element)
   g_return_if_fail (GST_ELEMENT_PARENT (element) == NULL);
 
   /* then check to see if the element's name is already taken in the bin */
-  if (gst_object_check_uniqueness (bin->children, 
-	                           GST_ELEMENT_NAME (element)) == FALSE)
-  {
+  if (gst_object_check_uniqueness (bin->children,
+          GST_ELEMENT_NAME (element)) == FALSE) {
     g_warning ("Name %s is not unique in bin %s, not adding\n",
-	       GST_ELEMENT_NAME (element), GST_ELEMENT_NAME (bin));
+        GST_ELEMENT_NAME (element), GST_ELEMENT_NAME (bin));
     return;
   }
 
@@ -454,7 +458,8 @@ gst_bin_add_func (GstBin *bin, GstElement *element)
 
   /* bump our internal state counter */
   state = GST_STATE (element);
-  while (state >>= 1) state_idx++;
+  while (state >>= 1)
+    state_idx++;
   bin->child_states[state_idx]++;
 
   /* now we have to deal with manager stuff 
@@ -465,8 +470,8 @@ gst_bin_add_func (GstBin *bin, GstElement *element)
     gst_bin_set_element_sched (element, sched);
   }
 
-  GST_CAT_DEBUG_OBJECT (GST_CAT_PARENTAGE, bin, "added element \"%s\"", 
-                        GST_OBJECT_NAME (element));
+  GST_CAT_DEBUG_OBJECT (GST_CAT_PARENTAGE, bin, "added element \"%s\"",
+      GST_OBJECT_NAME (element));
 
   g_signal_emit (G_OBJECT (bin), gst_bin_signals[ELEMENT_ADDED], 0, element);
 }
@@ -480,30 +485,29 @@ gst_bin_add_func (GstBin *bin, GstElement *element)
  * add a reference.
  */
 void
-gst_bin_add (GstBin *bin, GstElement *element)
+gst_bin_add (GstBin * bin, GstElement * element)
 {
   GstBinClass *bclass;
-  
+
   g_return_if_fail (GST_IS_BIN (bin));
   g_return_if_fail (GST_IS_ELEMENT (element));
 
   GST_CAT_INFO_OBJECT (GST_CAT_PARENTAGE, bin, "adding element \"%s\"",
-                       GST_OBJECT_NAME (element));
+      GST_OBJECT_NAME (element));
 
   bclass = GST_BIN_GET_CLASS (bin);
 
   if (bclass->add_element) {
     bclass->add_element (bin, element);
-  }
-  else {
+  } else {
     GST_ELEMENT_ERROR (bin, CORE, FAILED, (NULL),
-                       ("cannot add element %s to bin %s",
-	                GST_ELEMENT_NAME (element), GST_ELEMENT_NAME (bin)));
+        ("cannot add element %s to bin %s",
+            GST_ELEMENT_NAME (element), GST_ELEMENT_NAME (bin)));
   }
 }
 
 static void
-gst_bin_remove_func (GstBin *bin, GstElement *element)
+gst_bin_remove_func (GstBin * bin, GstElement * element)
 {
   gint state_idx = 0;
   GstElementState state;
@@ -514,7 +518,7 @@ gst_bin_remove_func (GstBin *bin, GstElement *element)
   /* the element must be in the bin's list of children */
   if (g_list_find (bin->children, element) == NULL) {
     g_warning ("no element \"%s\" in bin \"%s\"\n", GST_ELEMENT_NAME (element),
-	       GST_ELEMENT_NAME (bin));
+        GST_ELEMENT_NAME (bin));
     return;
   }
 
@@ -527,11 +531,12 @@ gst_bin_remove_func (GstBin *bin, GstElement *element)
 
   /* bump our internal state counter */
   state = GST_STATE (element);
-  while (state >>= 1) state_idx++;
+  while (state >>= 1)
+    state_idx++;
   bin->child_states[state_idx]--;
 
-  GST_CAT_INFO_OBJECT (GST_CAT_PARENTAGE, bin, "removed child \"%s\"", 
-                       GST_OBJECT_NAME (element));
+  GST_CAT_INFO_OBJECT (GST_CAT_PARENTAGE, bin, "removed child \"%s\"",
+      GST_OBJECT_NAME (element));
 
   /* ref as we're going to emit a signal */
   gst_object_ref (GST_OBJECT (element));
@@ -560,11 +565,12 @@ gst_bin_remove_func (GstBin *bin, GstElement *element)
  * #gst_object_ref before removing it from the bin.
  */
 void
-gst_bin_remove (GstBin *bin, GstElement *element)
+gst_bin_remove (GstBin * bin, GstElement * element)
 {
   GstBinClass *bclass;
 
-  GST_CAT_DEBUG (GST_CAT_PARENTAGE, "[%s]: trying to remove child %s", GST_ELEMENT_NAME (bin), GST_ELEMENT_NAME (element));
+  GST_CAT_DEBUG (GST_CAT_PARENTAGE, "[%s]: trying to remove child %s",
+      GST_ELEMENT_NAME (bin), GST_ELEMENT_NAME (element));
 
   g_return_if_fail (GST_IS_BIN (bin));
   g_return_if_fail (GST_IS_ELEMENT (element));
@@ -574,8 +580,7 @@ gst_bin_remove (GstBin *bin, GstElement *element)
 
   if (bclass->remove_element) {
     bclass->remove_element (bin, element);
-  }
-  else {
+  } else {
     g_warning ("cannot remove elements from bin %s\n", GST_ELEMENT_NAME (bin));
   }
 }
@@ -589,7 +594,7 @@ gst_bin_remove (GstBin *bin, GstElement *element)
  * Remove a list of elements from a bin. Uses #gst_bin_remove.
  */
 void
-gst_bin_remove_many (GstBin *bin, GstElement *element_1, ...)
+gst_bin_remove_many (GstBin * bin, GstElement * element_1, ...)
 {
   va_list args;
 
@@ -600,8 +605,8 @@ gst_bin_remove_many (GstBin *bin, GstElement *element_1, ...)
 
   while (element_1) {
     gst_bin_remove (bin, element_1);
-    
-    element_1 = va_arg (args, GstElement*);
+
+    element_1 = va_arg (args, GstElement *);
   }
 
   va_end (args);
@@ -618,59 +623,60 @@ gst_bin_remove_many (GstBin *bin, GstElement *element_1, ...)
  * of a child.
  */
 void
-gst_bin_child_state_change (GstBin *bin, GstElementState oldstate, 
-                            GstElementState newstate, GstElement *child)
+gst_bin_child_state_change (GstBin * bin, GstElementState oldstate,
+    GstElementState newstate, GstElement * child)
 {
   GstBinClass *bclass;
-  
+
   g_return_if_fail (GST_IS_BIN (bin));
   g_return_if_fail (GST_IS_ELEMENT (child));
 
   GST_CAT_LOG (GST_CAT_STATES, "child %s changed state in bin %s from %s to %s",
-               GST_ELEMENT_NAME (child), GST_ELEMENT_NAME (bin),
-               gst_element_state_get_name (oldstate),
-               gst_element_state_get_name (newstate));
+      GST_ELEMENT_NAME (child), GST_ELEMENT_NAME (bin),
+      gst_element_state_get_name (oldstate),
+      gst_element_state_get_name (newstate));
 
   bclass = GST_BIN_GET_CLASS (bin);
 
   if (bclass->child_state_change) {
     bclass->child_state_change (bin, oldstate, newstate, child);
-  }
-  else {
-    g_warning ("cannot signal state change of child %s to bin %s\n", 
-               GST_ELEMENT_NAME (child), GST_ELEMENT_NAME (bin));
+  } else {
+    g_warning ("cannot signal state change of child %s to bin %s\n",
+        GST_ELEMENT_NAME (child), GST_ELEMENT_NAME (bin));
   }
 }
 
 static void
-gst_bin_child_state_change_func (GstBin *bin, GstElementState oldstate, 
-                                 GstElementState newstate, GstElement *child)
+gst_bin_child_state_change_func (GstBin * bin, GstElementState oldstate,
+    GstElementState newstate, GstElement * child)
 {
   gint old_idx = 0, new_idx = 0, i;
 
-  while (oldstate >>= 1) old_idx++;
-  while (newstate >>= 1) new_idx++;
+  while (oldstate >>= 1)
+    old_idx++;
+  while (newstate >>= 1)
+    new_idx++;
 
   GST_LOCK (bin);
   bin->child_states[old_idx]--;
   bin->child_states[new_idx]++;
-  
+
   for (i = GST_NUM_STATES - 1; i >= 0; i--) {
     if (bin->child_states[i] != 0) {
       gint state = (1 << i);
+
       if (GST_STATE (bin) != state) {
-	GST_CAT_DEBUG_OBJECT (GST_CAT_STATES, bin,
-                              "highest child state is %s, changing bin state accordingly",
-                              gst_element_state_get_name (state));
-	GST_STATE_PENDING (bin) = state;
+        GST_CAT_DEBUG_OBJECT (GST_CAT_STATES, bin,
+            "highest child state is %s, changing bin state accordingly",
+            gst_element_state_get_name (state));
+        GST_STATE_PENDING (bin) = state;
         GST_UNLOCK (bin);
-	gst_bin_change_state_norecurse (bin);
-	if (state != GST_STATE (bin)) {
-          g_warning ("%s: state change in callback %d %d", 
-                     GST_ELEMENT_NAME (bin),
-                     state, GST_STATE (bin));
-	}
-	return;
+        gst_bin_change_state_norecurse (bin);
+        if (state != GST_STATE (bin)) {
+          g_warning ("%s: state change in callback %d %d",
+              GST_ELEMENT_NAME (bin), state, GST_STATE (bin));
+        }
+        return;
       }
       break;
     }
@@ -697,18 +703,18 @@ gst_bin_change_state (GstElement * element)
   pending = GST_STATE_PENDING (element);
   transition = GST_STATE_TRANSITION (element);
 
-  GST_CAT_DEBUG_OBJECT (GST_CAT_STATES, element, "changing childrens' state from %s to %s",
-                        gst_element_state_get_name (old_state),
-                        gst_element_state_get_name (pending));
+  GST_CAT_DEBUG_OBJECT (GST_CAT_STATES, element,
+      "changing state of children from %s to %s",
+      gst_element_state_get_name (old_state),
+      gst_element_state_get_name (pending));
 
   if (pending == GST_STATE_VOID_PENDING)
     return GST_STATE_SUCCESS;
 
-  if (old_state == pending)
-  {
-    GST_CAT_LOG_OBJECT (GST_CAT_STATES, element, 
-                        "old and pending state are both %s, returning",
-                        gst_element_state_get_name (pending));
+  if (old_state == pending) {
+    GST_CAT_LOG_OBJECT (GST_CAT_STATES, element,
+        "old and pending state are both %s, returning",
+        gst_element_state_get_name (pending));
     return GST_STATE_SUCCESS;
   }
 
@@ -725,48 +731,54 @@ gst_bin_change_state (GstElement * element)
 
     old_child_state = GST_STATE (child);
 
+    GST_CAT_DEBUG_OBJECT (GST_CAT_STATES, element,
+        "changing state of child %s from current %s to pending %s",
+        GST_ELEMENT_NAME (child), gst_element_state_get_name (old_child_state),
+        gst_element_state_get_name (pending));
+
     switch (gst_element_set_state (child, pending)) {
       case GST_STATE_FAILURE:
-	GST_CAT_INFO_OBJECT (GST_CAT_STATES, element,
-                             "child '%s' failed to go to state %d(%s)",
-                             GST_ELEMENT_NAME (child),
-                             pending, gst_element_state_get_name (pending));
+        GST_CAT_INFO_OBJECT (GST_CAT_STATES, element,
+            "child '%s' failed to go to state %d(%s)",
+            GST_ELEMENT_NAME (child),
+            pending, gst_element_state_get_name (pending));
 
-	gst_element_set_state (child, old_child_state);
-	/* There was a check for elements being in the same scheduling group
-	   here. Removed by dolphy <julien@moutte.net>. No matter the 
-	   scheduling group we should always return a failure. This change
-	   seems to work on my machine and fixes tons of issues. If anyone
-	   want to revert please tell me what it breaks first, Thanks. */
-	GST_STATE_PENDING (element) = old_state;
-	return GST_STATE_FAILURE;
-	break;
+        gst_element_set_state (child, old_child_state);
+        /* There was a check for elements being in the same scheduling group
+           here. Removed by dolphy <julien@moutte.net>. No matter the 
+           scheduling group we should always return a failure. This change
+           seems to work on my machine and fixes tons of issues. If anyone
+           want to revert please tell me what it breaks first, Thanks. */
+        GST_STATE_PENDING (element) = old_state;
+        return GST_STATE_FAILURE;
+        break;
       case GST_STATE_ASYNC:
-	GST_CAT_INFO_OBJECT (GST_CAT_STATES, element,
-                             "child '%s' is changing state asynchronously",
-                             GST_ELEMENT_NAME (child));
-	have_async = TRUE;
-	break;
+        GST_CAT_INFO_OBJECT (GST_CAT_STATES, element,
+            "child '%s' is changing state asynchronously",
+            GST_ELEMENT_NAME (child));
+        have_async = TRUE;
+        break;
       case GST_STATE_SUCCESS:
-        GST_CAT_DEBUG (GST_CAT_STATES, "child '%s' changed state to %d(%s) successfully",
-		   GST_ELEMENT_NAME (child), pending, gst_element_state_get_name (pending));
-        break;	
+        GST_CAT_DEBUG (GST_CAT_STATES,
+            "child '%s' changed state to %d(%s) successfully",
+            GST_ELEMENT_NAME (child), pending,
+            gst_element_state_get_name (pending));
+        break;
     }
   }
 
   GST_CAT_DEBUG_OBJECT (GST_CAT_STATES, element,
-                        "done changing bin's state from %s to %s, now in %s",
-                        gst_element_state_get_name (old_state),
-                        gst_element_state_get_name (pending),
-                        gst_element_state_get_name (GST_STATE (element)));
+      "done changing bin's state from %s to %s, now in %s",
+      gst_element_state_get_name (old_state),
+      gst_element_state_get_name (pending),
+      gst_element_state_get_name (GST_STATE (element)));
 
   if (have_async)
     ret = GST_STATE_ASYNC;
   else {
     if (parent_class->change_state) {
-      ret = parent_class->change_state(element);
-    }
-    else
+      ret = parent_class->change_state (element);
+    } else
       ret = GST_STATE_SUCCESS;
   }
   return ret;
@@ -783,8 +795,7 @@ gst_bin_change_state_norecurse (GstBin * bin)
     ret = parent_class->change_state (GST_ELEMENT (bin));
 
     return ret;
-  }
-  else
+  } else
     return GST_STATE_FAILURE;
 }
 
@@ -835,8 +846,8 @@ gst_bin_get_by_name (GstBin * bin, const gchar * name)
   g_return_val_if_fail (GST_IS_BIN (bin), NULL);
   g_return_val_if_fail (name != NULL, NULL);
 
-  GST_CAT_INFO (GST_CAT_PARENTAGE, "[%s]: looking up child element %s", 
-                GST_ELEMENT_NAME (bin), name);
+  GST_CAT_INFO (GST_CAT_PARENTAGE, "[%s]: looking up child element %s",
+      GST_ELEMENT_NAME (bin), name);
 
   children = bin->children;
   while (children) {
@@ -847,7 +858,7 @@ gst_bin_get_by_name (GstBin * bin, const gchar * name)
       GstElement *res = gst_bin_get_by_name (GST_BIN (child), name);
 
       if (res)
-	return res;
+        return res;
     }
     children = g_list_next (children);
   }
@@ -918,10 +929,10 @@ gst_bin_get_list (GstBin * bin)
  * Returns: An element inside the bin implementing the interface.
  */
 GstElement *
-gst_bin_get_by_interface (GstBin *bin, GType interface)
+gst_bin_get_by_interface (GstBin * bin, GType interface)
 {
   GList *walk;
-  
+
   g_return_val_if_fail (GST_IS_BIN (bin), NULL);
   g_return_val_if_fail (G_TYPE_IS_INTERFACE (interface), NULL);
 
@@ -931,9 +942,10 @@ gst_bin_get_by_interface (GstBin *bin, GType interface)
       return GST_ELEMENT (walk->data);
     if (GST_IS_BIN (walk->data)) {
       GstElement *ret;
+
       ret = gst_bin_get_by_interface (GST_BIN (walk->data), interface);
       if (ret)
-	return ret;
+        return ret;
     }
     walk = g_list_next (walk);
   }
@@ -954,10 +966,10 @@ gst_bin_get_by_interface (GstBin *bin, GType interface)
  * Returns: An element inside the bin implementing the interface.
  */
 GList *
-gst_bin_get_all_by_interface (GstBin *bin, GType interface)
+gst_bin_get_all_by_interface (GstBin * bin, GType interface)
 {
   GList *walk, *ret = NULL;
-    
+
   g_return_val_if_fail (GST_IS_BIN (bin), NULL);
   g_return_val_if_fail (G_TYPE_IS_INTERFACE (interface), NULL);
 
@@ -966,13 +978,13 @@ gst_bin_get_all_by_interface (GstBin *bin, GType interface)
     if (G_TYPE_CHECK_INSTANCE_TYPE (walk->data, interface))
       ret = g_list_prepend (ret, walk->data);
     if (GST_IS_BIN (walk->data)) {
-      ret = g_list_concat (ret, 
-	  gst_bin_get_all_by_interface (GST_BIN (walk->data), interface));
+      ret = g_list_concat (ret,
+          gst_bin_get_all_by_interface (GST_BIN (walk->data), interface));
     }
     walk = g_list_next (walk);
   }
 
-  return ret; 
+  return ret;
 }
 
 /**
@@ -988,7 +1000,7 @@ gst_bin_get_all_by_interface (GstBin *bin, GType interface)
  *          this function returns #GST_STATE_FAILURE.
  */
 GstElementStateReturn
-gst_bin_sync_children_state (GstBin *bin)
+gst_bin_sync_children_state (GstBin * bin)
 {
   GList *children;
   GstElement *element;
@@ -999,31 +1011,33 @@ gst_bin_sync_children_state (GstBin *bin)
 
   state = GST_STATE (bin);
   children = bin->children;
-  GST_CAT_INFO (GST_CAT_STATES, "syncing state of children with bin \"%s\"'s state %s",
-            GST_ELEMENT_NAME (bin), gst_element_state_get_name (state));
+  GST_CAT_INFO (GST_CAT_STATES,
+      "syncing state of children with bin \"%s\"'s state %s",
+      GST_ELEMENT_NAME (bin), gst_element_state_get_name (state));
 
   while (children) {
     element = GST_ELEMENT (children->data);
     children = children->next;
-    if (GST_STATE(element) != state) {
+    if (GST_STATE (element) != state) {
       switch (gst_element_set_state (element, state)) {
-      case GST_STATE_SUCCESS:
-	break;
-      case GST_STATE_ASYNC:
-	if (ret == GST_STATE_SUCCESS)
-	  ret = GST_STATE_ASYNC;
-	break;
-      case GST_STATE_FAILURE:
-	ret = GST_STATE_FAILURE;
-      default:
-        /* make sure gst_element_set_state never returns this */
-        g_assert_not_reached ();
+        case GST_STATE_SUCCESS:
+          break;
+        case GST_STATE_ASYNC:
+          if (ret == GST_STATE_SUCCESS)
+            ret = GST_STATE_ASYNC;
+          break;
+        case GST_STATE_FAILURE:
+          ret = GST_STATE_FAILURE;
+        default:
+          /* make sure gst_element_set_state never returns this */
+          g_assert_not_reached ();
       }
     }
   }
 
   return ret;
 }
+
 #ifndef GST_DISABLE_LOADSAVE
 static xmlNodePtr
 gst_bin_save_thyself (GstObject * object, xmlNodePtr parent)
@@ -1038,8 +1052,8 @@ gst_bin_save_thyself (GstObject * object, xmlNodePtr parent)
 
   childlist = xmlNewChild (parent, NULL, "children", NULL);
 
-  GST_CAT_INFO (GST_CAT_XML, "[%s]: saving %d children", 
-                GST_ELEMENT_NAME (bin), bin->numchildren);
+  GST_CAT_INFO (GST_CAT_XML, "[%s]: saving %d children",
+      GST_ELEMENT_NAME (bin), bin->numchildren);
 
   children = bin->children;
   while (children) {
@@ -1060,20 +1074,22 @@ gst_bin_restore_thyself (GstObject * object, xmlNodePtr self)
 
   while (field) {
     if (!strcmp (field->name, "children")) {
-      GST_CAT_INFO (GST_CAT_XML, "[%s]: loading children", GST_ELEMENT_NAME (object));
+      GST_CAT_INFO (GST_CAT_XML, "[%s]: loading children",
+          GST_ELEMENT_NAME (object));
       childlist = field->xmlChildrenNode;
       while (childlist) {
-	if (!strcmp (childlist->name, "element")) {
-	  GstElement *element = gst_xml_make_element (childlist, GST_OBJECT (bin));
-          
+        if (!strcmp (childlist->name, "element")) {
+          GstElement *element =
+              gst_xml_make_element (childlist, GST_OBJECT (bin));
+
           /* it had to be parented to find the pads, now we ref and unparent so
            * we can add it to the bin */
           gst_object_ref (GST_OBJECT (element));
           gst_object_unparent (GST_OBJECT (element));
-          
-	  gst_bin_add (bin, element);
-	}
-	childlist = childlist->next;
+
+          gst_bin_add (bin, element);
+        }
+        childlist = childlist->next;
       }
     }
 
@@ -1094,14 +1110,12 @@ gst_bin_iterate_func (GstBin * bin)
 
     if (state == GST_SCHEDULER_STATE_RUNNING) {
       return TRUE;
-    }
-    else if (state == GST_SCHEDULER_STATE_ERROR) {
+    } else if (state == GST_SCHEDULER_STATE_ERROR) {
       gst_element_set_state (GST_ELEMENT (bin), GST_STATE_PAUSED);
     }
-  }
-  else {
-    g_warning ("bin \"%s\" is not the managing bin, can't be iterated on!\n", 
-	       GST_ELEMENT_NAME (bin));
+  } else {
+    g_warning ("bin \"%s\" is not the managing bin, can't be iterated on!\n",
+        GST_ELEMENT_NAME (bin));
   }
 
   return FALSE;
@@ -1117,7 +1131,7 @@ gst_bin_iterate_func (GstBin * bin)
  *          can be used to determine it the bin is in EOS.
  */
 gboolean
-gst_bin_iterate (GstBin *bin)
+gst_bin_iterate (GstBin * bin)
 {
   gboolean running;
 
@@ -1134,10 +1148,11 @@ gst_bin_iterate (GstBin *bin)
   GST_CAT_LOG_OBJECT (GST_CAT_DATAFLOW, bin, "finished iteration");
 
   if (!running) {
-    if (GST_STATE (bin) == GST_STATE_PLAYING && 
-	GST_STATE_PENDING (bin) == GST_STATE_VOID_PENDING) {
-      GST_CAT_DEBUG (GST_CAT_DATAFLOW, "[%s]: polling for child shutdown after useless iteration",
-	             GST_ELEMENT_NAME (bin));
+    if (GST_STATE (bin) == GST_STATE_PLAYING &&
+        GST_STATE_PENDING (bin) == GST_STATE_VOID_PENDING) {
+      GST_CAT_DEBUG (GST_CAT_DATAFLOW,
+          "[%s]: polling for child shutdown after useless iteration",
+          GST_ELEMENT_NAME (bin));
       g_usleep (1);
       running = TRUE;
     }
