@@ -29,10 +29,11 @@
 
 #include <string.h>
 
-static void		gst_plugin_feature_class_init		(GstPluginFeatureClass *klass);
-static void		gst_plugin_feature_init			(GstPluginFeature *feature);
+static void gst_plugin_feature_class_init (GstPluginFeatureClass * klass);
+static void gst_plugin_feature_init (GstPluginFeature * feature);
 
 static GObjectClass *parent_class = NULL;
+
 /* static guint gst_plugin_feature_signals[LAST_SIGNAL] = { 0 }; */
 
 GType
@@ -53,24 +54,25 @@ gst_plugin_feature_get_type (void)
       (GInstanceInitFunc) gst_plugin_feature_init,
       NULL
     };
-    plugin_feature_type = g_type_register_static (G_TYPE_OBJECT, "GstPluginFeature", 
-		    				  &plugin_feature_info, G_TYPE_FLAG_ABSTRACT);
+    plugin_feature_type =
+        g_type_register_static (G_TYPE_OBJECT, "GstPluginFeature",
+        &plugin_feature_info, G_TYPE_FLAG_ABSTRACT);
   }
   return plugin_feature_type;
 }
 
 static void
-gst_plugin_feature_class_init (GstPluginFeatureClass *klass)
+gst_plugin_feature_class_init (GstPluginFeatureClass * klass)
 {
   GObjectClass *gobject_class;
 
-  gobject_class = (GObjectClass*) klass;
+  gobject_class = (GObjectClass *) klass;
 
   parent_class = g_type_class_ref (G_TYPE_OBJECT);
 }
 
 static void
-gst_plugin_feature_init (GstPluginFeature *feature)
+gst_plugin_feature_init (GstPluginFeature * feature)
 {
   feature->manager = NULL;
 }
@@ -85,25 +87,25 @@ gst_plugin_feature_init (GstPluginFeature *feature)
  * Returns: a boolean indicating the feature is loaded.
  */
 gboolean
-gst_plugin_feature_ensure_loaded (GstPluginFeature *feature)
+gst_plugin_feature_ensure_loaded (GstPluginFeature * feature)
 {
   GstPlugin *plugin;
-  
+
   g_return_val_if_fail (feature != NULL, FALSE);
   g_return_val_if_fail (GST_IS_PLUGIN_FEATURE (feature), FALSE);
 
   plugin = (GstPlugin *) (feature->manager);
 
   if (plugin && !gst_plugin_is_loaded (plugin)) {
-#ifndef GST_DISABLE_REGISTRY 
+#ifndef GST_DISABLE_REGISTRY
     if (GST_IS_REGISTRY (plugin->manager)) {
-      GST_CAT_DEBUG (GST_CAT_PLUGIN_LOADING, 
-	         "loading plugin %s for feature", plugin->desc.name);
+      GST_CAT_DEBUG (GST_CAT_PLUGIN_LOADING,
+          "loading plugin %s for feature", plugin->desc.name);
 
-      if (gst_registry_load_plugin (GST_REGISTRY (plugin->manager), plugin) != GST_REGISTRY_OK)
-	return FALSE;
-    }
-    else
+      if (gst_registry_load_plugin (GST_REGISTRY (plugin->manager),
+              plugin) != GST_REGISTRY_OK)
+        return FALSE;
+    } else
 #endif /* GST_DISABLE_REGISTRY */
       return FALSE;
   }
@@ -118,13 +120,13 @@ gst_plugin_feature_ensure_loaded (GstPluginFeature *feature)
  * in the plugin and will eventually unload the plugin
  */
 void
-gst_plugin_feature_unload_thyself (GstPluginFeature *feature)
+gst_plugin_feature_unload_thyself (GstPluginFeature * feature)
 {
-  GstPluginFeatureClass *oclass; 
+  GstPluginFeatureClass *oclass;
 
   g_return_if_fail (feature != NULL);
   g_return_if_fail (GST_IS_PLUGIN_FEATURE (feature));
-  
+
   oclass = GST_PLUGIN_FEATURE_GET_CLASS (feature);
 
   if (oclass->unload_thyself)
@@ -132,12 +134,14 @@ gst_plugin_feature_unload_thyself (GstPluginFeature *feature)
 }
 
 gboolean
-gst_plugin_feature_type_name_filter (GstPluginFeature *feature,
-		                     GstTypeNameData *data)
+gst_plugin_feature_type_name_filter (GstPluginFeature * feature,
+    GstTypeNameData * data)
 {
-  return ((data->type == 0    || data->type == G_OBJECT_TYPE (feature)) &&
-          (data->name == NULL || !strcmp (data->name, GST_PLUGIN_FEATURE_NAME (feature))));
+  return ((data->type == 0 || data->type == G_OBJECT_TYPE (feature)) &&
+      (data->name == NULL
+          || !strcmp (data->name, GST_PLUGIN_FEATURE_NAME (feature))));
 }
+
 /**
  * gst_plugin_feature_set_rank:
  * @feature: feature to rank
@@ -147,13 +151,14 @@ gst_plugin_feature_type_name_filter (GstPluginFeature *feature,
  * the most appropriate feature.
  */
 void
-gst_plugin_feature_set_rank (GstPluginFeature *feature, guint rank)
+gst_plugin_feature_set_rank (GstPluginFeature * feature, guint rank)
 {
   g_return_if_fail (feature != NULL);
   g_return_if_fail (GST_IS_PLUGIN_FEATURE (feature));
 
   feature->rank = rank;
 }
+
 /**
  * gst_plugin_feature_set_name:
  * @feature: a feature
@@ -164,7 +169,7 @@ gst_plugin_feature_set_rank (GstPluginFeature *feature, guint rank)
  * allowed.
  */
 void
-gst_plugin_feature_set_name (GstPluginFeature *feature, const gchar *name)
+gst_plugin_feature_set_name (GstPluginFeature * feature, const gchar * name)
 {
   g_return_if_fail (GST_IS_PLUGIN_FEATURE (feature));
   g_return_if_fail (name != NULL);
@@ -175,6 +180,7 @@ gst_plugin_feature_set_name (GstPluginFeature *feature, const gchar *name)
     feature->name = g_strdup (name);
   }
 }
+
 /**
  * gst_plugin_feature_get rank:
  * @feature: a feature
@@ -184,12 +190,13 @@ gst_plugin_feature_set_name (GstPluginFeature *feature, const gchar *name)
  * Returns: The rank of the feature
  */
 guint
-gst_plugin_feature_get_rank (GstPluginFeature *feature)
+gst_plugin_feature_get_rank (GstPluginFeature * feature)
 {
   g_return_val_if_fail (GST_IS_PLUGIN_FEATURE (feature), GST_RANK_NONE);
-  
+
   return feature->rank;
 }
+
 /**
  * gst_plugin_feature_get_name:
  * @feature: a feature
@@ -199,10 +206,9 @@ gst_plugin_feature_get_rank (GstPluginFeature *feature)
  * Returns: the name
  */
 G_CONST_RETURN gchar *
-gst_plugin_feature_get_name (GstPluginFeature *feature)
+gst_plugin_feature_get_name (GstPluginFeature * feature)
 {
   g_return_val_if_fail (GST_IS_PLUGIN_FEATURE (feature), NULL);
-  
+
   return feature->name;
 }
-
