@@ -53,12 +53,14 @@ typedef enum {
 typedef GstStructure GstTagList;
 #define GST_TAG_LIST(x)		((GstTagList *) (x))
 #define GST_IS_TAG_LIST(x)	(gst_is_tag_list (GST_TAG_LIST (x)))
+#define GST_TYPE_TAG_LIST       (gst_tag_list_get_type ())
 
 typedef void		(* GstTagForeachFunc)	(const GstTagList *list, const gchar *tag, gpointer user_data);
 typedef void		(* GstTagMergeFunc)	(GValue *dest, const GValue *src);
 
 /* initialize tagging system */
 void		_gst_tag_initialize		(void);
+GType           gst_tag_list_get_type           (void);
 
 void		gst_tag_register		(gchar *		name,
 						 GstTagFlag		flag,
@@ -79,6 +81,7 @@ G_CONST_RETURN gchar *
 		gst_tag_get_nick		(const gchar *		tag);
 G_CONST_RETURN gchar *
 		gst_tag_get_description		(const gchar *		tag);
+GstTagFlag	gst_tag_get_flag		(const gchar *		tag);
 gboolean	gst_tag_is_fixed		(const gchar *		tag);
 
 /* tag lists */
@@ -231,6 +234,8 @@ GstTagList *	gst_event_tag_get_list		(GstEvent *		tag_event);
 #define GST_TAG_COMMENT			"comment"
 #define GST_TAG_TRACK_NUMBER		"track-number"
 #define GST_TAG_TRACK_COUNT		"track-count"
+#define GST_TAG_ALBUM_VOLUME_NUMBER	"album-disc-number"
+#define GST_TAG_ALBUM_VOLUME_COUNT	"album-disc-count"
 #define GST_TAG_LOCATION		"location"
 #define GST_TAG_DESCRIPTION		"description"
 #define GST_TAG_VERSION			"version"
@@ -242,6 +247,8 @@ GstTagList *	gst_event_tag_get_list		(GstEvent *		tag_event);
 #define GST_TAG_PERFORMER		"performer"
 #define GST_TAG_DURATION		"duration"
 #define GST_TAG_CODEC			"codec"
+#define GST_TAG_VIDEO_CODEC		"video-codec"
+#define GST_TAG_AUDIO_CODEC		"audio-codec"
 #define GST_TAG_BITRATE			"bitrate"
 #define GST_TAG_NOMINAL_BITRATE		"nominal-bitrate"
 #define GST_TAG_MINIMUM_BITRATE		"minimum-bitrate"
@@ -254,7 +261,6 @@ GstTagList *	gst_event_tag_get_list		(GstEvent *		tag_event);
 #define GST_TAG_ALBUM_GAIN  		"replaygain-album-gain"
 #define GST_TAG_ALBUM_PEAK		"replaygain-album-peak"
 
-
 G_END_DECLS
 
 #endif /* __GST_EVENT_H__ */
